@@ -6,6 +6,7 @@ import numpy as np
 from io import BytesIO
 from pyquaternion import Quaternion
 from typing import Any
+from scipy.spatial.transform import Rotation as R
 
 
 from .camera import LidarCamera
@@ -276,7 +277,7 @@ class LidarFrame:
                 gs[index + len(extrinsics_position) + 1, 1]
             )
             value = getattr(self.cameras[camera_id], "rotation")
-            value = Quaternion(matrix=value)
+            value = Quaternion(R.from_matrix(value).as_quat())
             globals()[key] = Slider(
                 globals()[f"ax{key}"],
                 f"{key}",
