@@ -28,7 +28,7 @@ def parse_xyz(obj):
 
 
 def parse_quaternion(obj):
-    return np.array([obj['w'], obj["x"], obj["y"], obj["z"]])
+    return np.array([obj["w"], obj["x"], obj["y"], obj["z"]])
 
 
 def parse_cuboid_frame(frame):
@@ -52,31 +52,26 @@ def get_api_client() -> ScaleClient:
 
 
 def get_default_template():
-    return {
-        "task_id": None,
-        "callback_url": "http://example.com",
-        "instruction": "Please label all objects",
-        "labels": ["Object"],
-        "meters_per_unit": 1,
-        "max_distance_meters": 20,
-    }
+    return {"task_id": None}
 
 
 # S3 helpers
 
+
 def get_s3_client():
     global _S3
     if _S3 is None:
         _S3 = boto3.client("s3")
     return _S3
 
+
 def fp_md5(fp: BytesIO):
     fp.seek(0)
     md5 = hashlib.md5()
-    buf = fp.read(2 ** 20)
+    buf = fp.read(2**20)
     while buf:
         md5.update(buf)
-        buf = fp.read(2 ** 20)
+        buf = fp.read(2**20)
     fp.seek(0)
     return md5.hexdigest()
 
