@@ -173,9 +173,7 @@ class LidarScene:
         if base_url is None:
             base_url = self.base_url
         return dict(
-            frames=[
-                "%s/frame-%s.json" % (base_url, frame.id) for frame in self.frames
-            ]
+            frames=["%s/frame-%s.json" % (base_url, frame.id) for frame in self.frames]
         )
 
     def s3_upload(
@@ -259,7 +257,9 @@ class LidarScene:
         func = partial(LidarFrame.scale_file_upload, project_name=project_name)
         self.scale_file_attachments = p.map(func, self.frames)
 
-        print(f"Finishes uploading scene to Scale file, uploaded {len(self.scale_file_attachments)} frames")
+        print(
+            f"Finishes uploading scene to Scale file, uploaded {len(self.scale_file_attachments)} frames"
+        )
         return self.scale_file_attachments
 
     def save_task(self, filepath: str, template=None):
